@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = 2.4;
+our $VERSION = 2.5; # local revision: b
 
 1;
 
@@ -14,7 +14,7 @@ sub recommended {
     $class->new(14);
 }
 
-sub new { 
+sub new {
     my $class = shift;
     my $this  = bless {
     }, $class;
@@ -27,8 +27,8 @@ sub new {
     return $this;
 }
 
-sub set_days { 
-    my $this = shift; 
+sub set_days {
+    my $this = shift;
     my $arg  = int(shift);
 
     croak "days must be a positive non-zero integer" if $arg <= 0;
@@ -46,7 +46,7 @@ sub insert {
 
     my $y_close = $this->{y_close};
     while( defined( my $point = shift ) ) {
-        croak "insert takes three touples [high, low, close]" unless ref $point eq "ARRAY" and @$point == 3;
+        croak "insert takes three tuple [high, low, close]" unless ref $point eq "ARRAY" and @$point == 3;
         my ($t_high, $t_low, $t_close) = @$point;
 
         if( defined $y_close ) {
@@ -128,7 +128,7 @@ Math::Business::ATR - Technical Analysis: Average True Range
       [ 5, 4, 4.5 ],
   );
 
-  # choose one: 
+  # choose one:
   $atr->insert( @data_points );
   $atr->insert( $_ ) for @data_points;
 
@@ -154,7 +154,7 @@ bidding up (or selling down) a stock.
 
 =head1 AUTHOR
 
-Paul Miller <jettero@cpan.org>
+Paul Miller C<< <jettero@cpan.org> >>
 
 I am using this software in my own projects...  If you find bugs, please please
 please let me know.
@@ -167,12 +167,20 @@ join: L<http://groups.google.com/group/stockmonkey/>.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008 Paul Miller -- LGPL [Software::License::LGPL_2_1]
+Copyright (c) 2010 Paul Miller
 
-    perl -MSoftware::License::LGPL_2_1 \
-         -e '$l = Software::License::LGPL_2_1->new({
-             holder=>"Paul Miller"});
-             print $l->fulltext' | less
+=head1 LICENSE
+
+This module is free software.  You can redistribute it and/or
+modify it under the terms of the Artistic License 2.0.
+
+This program is distributed in the hope that it will be useful,
+but without any warranty; without even the implied warranty of
+merchantability or fitness for a particular purpose.
+
+[This software may have had previous licenses, of which the current maintainer
+is completely unaware.  If this is so, it is possible the above license is
+incorrect or invalid.]
 
 =head1 SEE ALSO
 
