@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = 2.3;
+our $VERSION = 2.5;
 
 1;
 
@@ -14,7 +14,7 @@ sub recommended {
     $class->new(20, 2);
 }
 
-sub new { 
+sub new {
     my $class = shift;
     my $this  = bless {
         dev => [],
@@ -31,16 +31,16 @@ sub new {
     return $this;
 }
 
-sub set_deviations { 
-    my $this = shift; 
+sub set_deviations {
+    my $this = shift;
     my $arg  = int shift;
 
     croak "deviations must be a positive non-zero integer" if $arg <= 0;
     $this->{K} = $arg;
 }
 
-sub set_days { 
-    my $this = shift; 
+sub set_days {
+    my $this = shift;
     my $arg  = int shift;
 
     croak "days must be a positive non-zero integer" if $arg <= 0;
@@ -101,8 +101,6 @@ sub insert {
     }
 }
 
-*start_with = *insert;
-
 sub query {
     my $this = shift;
 
@@ -131,11 +129,11 @@ Math::Business::BollingerBands - Technical Analysis: Bollinger Bands
   my $bb = Math::Business::BollingerBands->recommended;
 
   my @closing_values = qw(
-      3 4 4 5 6 5 6 5 5 5 5 
-      6 6 6 6 7 7 7 8 8 8 8 
+      3 4 4 5 6 5 6 5 5 5 5
+      6 6 6 6 7 7 7 8 8 8 8
   );
 
-  # choose one: 
+  # choose one:
   $bb->insert( @closing_values );
   $bb->insert( $_ ) for @closing_values;
 
@@ -147,9 +145,6 @@ Math::Business::BollingerBands - Technical Analysis: Bollinger Bands
       print "BB: n/a.\n";
   }
 
-  # you may use this to kick start 
-  $bb->start_with( @closes );
-
 =head1 RESEARCHER
 
 The Bollinger Bands were designed by John Bollinger in the 1980s.
@@ -168,7 +163,7 @@ down.
 
 =head1 AUTHOR
 
-Paul Miller <jettero@cpan.org>
+Paul Miller C<< <jettero@cpan.org> >>
 
 I am using this software in my own projects...  If you find bugs, please please
 please let me know.
@@ -176,14 +171,25 @@ please let me know.
 I normally hang out on #perl on freenode, so you can try to get immediate
 gratification there if you like.  L<irc://irc.freenode.net/perl>
 
+There is also a mailing list with very light traffic that you might want to
+join: L<http://groups.google.com/group/stockmonkey/>.
+
 =head1 COPYRIGHT
 
-Copyright (c) 2008 Paul Miller -- LGPL [Software::License::LGPL_2_1]
+Copyright (c) 2010 Paul Miller
 
-    perl -MSoftware::License::LGPL_2_1 \
-         -e '$l = Software::License::LGPL_2_1->new({
-             holder=>"Paul Miller"});
-             print $l->fulltext' | less
+=head1 LICENSE
+
+This module is free software.  You can redistribute it and/or
+modify it under the terms of the Artistic License 2.0.
+
+This program is distributed in the hope that it will be useful,
+but without any warranty; without even the implied warranty of
+merchantability or fitness for a particular purpose.
+
+[This software may have had previous licenses, of which the current maintainer
+is completely unaware.  If this is so, it is possible the above license is
+incorrect or invalid.]
 
 =head1 SEE ALSO
 
