@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = 2.4;
+our $VERSION = 2.41; # local revision: b
 
 use Math::Business::ATR;
 
@@ -16,7 +16,7 @@ sub recommended {
     $class->new(14);
 }
 
-sub new { 
+sub new {
     my $class = shift;
     my $this  = bless {
         ATR => new Math::Business::ATR,
@@ -30,8 +30,8 @@ sub new {
     return $this;
 }
 
-sub set_days { 
-    my $this = shift; 
+sub set_days {
+    my $this = shift;
     my $arg  = int(shift);
 
     croak "days must be a positive non-zero integer" if $arg <= 0;
@@ -47,7 +47,7 @@ sub insert {
 
     my $y_point = $this->{y};
     while( defined( my $point = shift ) ) {
-        croak "insert takes three touples (high, low, close)" unless ref $point eq "ARRAY" and @$point == 3;
+        croak "insert takes three tuple (high, low, close)" unless ref $point eq "ARRAY" and @$point == 3;
         my ($t_high, $t_low, $t_close) = @$point;
 
         if( defined $y_point ) {
@@ -89,7 +89,8 @@ sub insert {
                     my $MDI = $this->{MDI} = $aMDM / $ATR;
 
                     my $DI = abs( $PDI - $MDI );
-                    my $DX = $DI / ($PDI + $MDI);
+                    my $DX = $DI ? $DI / ($PDI + $MDI) : 0;
+                    # 0/0 is indeterminent form, but I think 0 makes sense
 
                     $this->{ADX} = $R * $this->{ADX} + $R1 * $DX;
                 }
@@ -119,7 +120,8 @@ sub insert {
                         my $MDI = $this->{MDI} = $aMDM / $ATR;
 
                         my $DI = abs( $PDI - $MDI );
-                        my $DX = $DI / ($PDI + $MDI);
+                        my $DX = $DI ? $DI / ($PDI + $MDI) : 0;
+                        # 0/0 is indeterminent form, but I think 0 makes sense
 
                         $this->{ADX} = $DX; # is this right?  No idea...  I assume this is well documented in his book
                     }
@@ -175,7 +177,7 @@ Math::Business::DMI - Technical Analysis: Directional Movement Index (aka ADX)
       [ 5, 4, 4.5 ],
   );
 
-  # choose one: 
+  # choose one:
   $dmi->insert( @data_points );
   $dmi->insert( $_ ) for @data_points;
 
@@ -210,13 +212,13 @@ The DMI uses the ATR to try to measure volatility.
 
 NOTE: The +DI, -DI and ADX returned by this module are probabilities ranging
 from 0 to 1.  Most sources seem to show the DMI values as numbers from 0 to
-100.  Simply multiply the three touple by 100 to get this result.
+100.  Simply multiply the three tuple by 100 to get this result.
 
     my @DMI = map { 100*$_ } = $dmi->query;
 
 =head1 AUTHOR
 
-Paul Miller <jettero@cpan.org>
+Paul Miller C<< <jettero@cpan.org> >>
 
 I am using this software in my own projects...  If you find bugs, please please
 please let me know.
@@ -229,12 +231,24 @@ join: L<http://groups.google.com/group/stockmonkey/>.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008 Paul Miller -- LGPL [Software::License::LGPL_2_1]
+Copyright (c) 2010 Paul Miller
 
-    perl -MSoftware::License::LGPL_2_1 \
-         -e '$l = Software::License::LGPL_2_1->new({
-             holder=>"Paul Miller"});
-             print $l->fulltext' | less
+=head1 LICENSE
+
+This module is free software.  You can redistribute it and/or
+modify it under the terms of the Artistic License 2.0.
+
+This program is distributed in the hope that it will be useful,
+but without any warranty; without even the implied warranty of
+merchantability or fitness for a particular purpose.
+
+[This software may have had previous licenses, of which the current maintainer
+is completely unaware.  If this is so, it is possible the above license is
+incorrect or invalid.]
+
+=head1 THANKS
+
+BobBack C<< <drchap...@gmail.com> >>
 
 =head1 SEE ALSO
 
