@@ -4,13 +4,13 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = 2.3;
+our $VERSION = 2.5;
 
 1;
 
 sub recommended { croak "no recommendation" }
 
-sub new { 
+sub new {
     my $class = shift;
     my $this = bless {
         EMA => undef,
@@ -26,8 +26,8 @@ sub new {
     return $this;
 }
 
-sub set_days { 
-    my $this = shift; 
+sub set_days {
+    my $this = shift;
     my $arg  = int(shift);
 
     croak "days must be a positive non-zero integer" if $arg <= 0;
@@ -53,6 +53,7 @@ sub insert {
                    $sum += $_ for @$p;
 
                 $this->{EMA} = ( $this->{R} * $Yt ) + ( $this->{R1} * ($sum/$N) );
+                delete $this->{_p};
 
             } else {
                 push @{$this->{_p}}, $Yt;
@@ -61,13 +62,6 @@ sub insert {
     }
 }
 
-sub start_with {
-    my $this = shift;
-       $this->{EMA} = shift;
-
-    croak "undefined arg to start_with" unless defined $this->{EMA};
-}
-
 sub query {
     my $this = shift;
 
@@ -88,8 +82,8 @@ Math::Business::EMA - Technical Analysis: Exponential Moving Average
      $avg->set_days(7);
 
   my @closing_values = qw(
-      3 4 4 5 6 5 6 5 5 5 5 
-      6 6 6 6 7 7 7 8 8 8 8 
+      3 4 4 5 6 5 6 5 5 5 5
+      6 6 6 6 7 7 7 8 8 8 8
   );
 
   # choose one:
@@ -97,23 +91,19 @@ Math::Business::EMA - Technical Analysis: Exponential Moving Average
   $avg->insert( $_ ) for @closing_values;
 
   if( defined(my $q = $avg->query) ) {
-      print "value: $q.\n";  
+      print "value: $q.\n";
 
   } else {
       print "value: n/a.\n";
   }
 
-To avoid recalculating huge lists when you add a few new values on the end:
-
-  $avg->start_with( $the_last_calculated_value );
-
 For short, you can skip the set_days() by suppling the setting to new():
 
   my $longer_ema = new Math::Business::EMA(10);
 
 =head1 AUTHOR
 
-Paul Miller <jettero@cpan.org>
+Paul Miller C<< <jettero@cpan.org> >>
 
 I am using this software in my own projects...  If you find bugs, please please
 please let me know.
@@ -121,14 +111,25 @@ please let me know.
 I normally hang out on #perl on freenode, so you can try to get immediate
 gratification there if you like.  L<irc://irc.freenode.net/perl>
 
+There is also a mailing list with very light traffic that you might want to
+join: L<http://groups.google.com/group/stockmonkey/>.
+
 =head1 COPYRIGHT
 
-Copyright (c) 2008 Paul Miller -- LGPL [Software::License::LGPL_2_1]
+Copyright (c) 2010 Paul Miller
 
-    perl -MSoftware::License::LGPL_2_1 \
-         -e '$l = Software::License::LGPL_2_1->new({
-             holder=>"Paul Miller"});
-             print $l->fulltext' | less
+=head1 LICENSE
+
+This module is free software.  You can redistribute it and/or
+modify it under the terms of the Artistic License 2.0.
+
+This program is distributed in the hope that it will be useful,
+but without any warranty; without even the implied warranty of
+merchantability or fitness for a particular purpose.
+
+[This software may have had previous licenses, of which the current maintainer
+is completely unaware.  If this is so, it is possible the above license is
+incorrect or invalid.]
 
 =head1 SEE ALSO
 
