@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = 2.3;
+our $VERSION = 2.5; # local revision: b
 
 use Math::Business::SMA;
 use Math::Business::EMA;
@@ -17,7 +17,7 @@ sub recommended {
     $class->new(14);
 }
 
-sub new { 
+sub new {
     my $class = shift;
     my $this  = bless {
         U   => Math::Business::EMA->new,
@@ -38,7 +38,10 @@ sub set_alpha {
     my $this  = shift;
     my $alpha = shift;
 
-    my $days = 2*$alpha - 1;
+    # NOTE: this alpha is different than you might think ... it's really inverse alpha
+    # Wilder uses alpha=14 instead of alpha=(1/14) like you might expect
+
+    my $days = 2*$alpha - 1; # so days is 2*$alpha-1 instead of the expected 2*(1/$alpha)-1
 
     eval { $this->set_days( $days ) };
     croak "set_alpha() is basically set_days(2*$alpha-1), which complained: $@" if $@;
@@ -72,8 +75,8 @@ sub set_cutler {
     }
 }
 
-sub set_days { 
-    my $this = shift; 
+sub set_days {
+    my $this = shift;
     my $arg  = int(shift);
 
     croak "days must be a positive non-zero integer" if $arg <= 0;
@@ -123,19 +126,6 @@ sub insert {
     $this->{cy} = $close_yesterday;
 }
 
-sub start_with {
-    my $this = shift;
-    my ($U,$D,$cy) = @_;
-
-    $this->{U}->start_with( $U );
-    $this->{D}->start_with( $U );
-    $this->{cy} = $cy;
-}
-
-sub query_EMA_U { my $this = shift; $this->{U}->query }
-sub query_EMA_D { my $this = shift; $this->{D}->query }
-sub query_cy    { my $this = shift; $this->{cy} }
-
 sub query {
     my $this = shift;
 
@@ -163,11 +153,11 @@ Math::Business::RSI - Technical Analysis: Relative Strength Index
   my $rsi = Math::Business::RSI->recommended;
 
   my @closing_values = qw(
-      3 4 4 5 6 5 6 5 5 5 5 
-      6 6 6 6 7 7 7 8 8 8 8 
+      3 4 4 5 6 5 6 5 5 5 5
+      6 6 6 6 7 7 7 8 8 8 8
   );
 
-  # choose one: 
+  # choose one:
   $rsi->insert( @closing_values );
   $rsi->insert( $_ ) for @closing_values;
 
@@ -178,14 +168,6 @@ Math::Business::RSI - Technical Analysis: Relative Strength Index
       print "RSI: n/a.\n";
   }
 
-  # you may use this to kick start 
-  $rsi->start_with( $U, $D, $cy );
-
-  # you may fetch those values with these
-  my $U  = $rsi->query_EMA_U;
-  my $D  = $rsi->query_EMA_D;
-  my $cy = $rsi->query_cy; # (close yesterday)
-
 =head1 RESEARCHER
 
 The RSI was designed by J. Welles Wilder Jr in 1978.
@@ -198,11 +180,13 @@ Therefore, moving above the upper threshold is a selling signal, whlie moving
 below the lower threshold is a signal to buy.
 
 Oddly, RSI(14) uses a "smoothing period" of 14 days -- referring to an alpha of
-1/14.  This means the EMA[N]u/EMA[N]d has N set to 27!
+1/14.  This means the EMA[N]u/EMA[N]d has N set to 27.  This also means the
+alpha is upside of other alpha you might see.  RSI(14) actually uses an alpha
+of ~0.0714, but set_alpha() takes the inverse to make C<$rsi->set_alpha(14)>
+work.
 
-Therefore, in addition to the usual C<set_days()> there is also a C<set_alpha()>
-(which is used by C<new()>).  C<set_days(27)> is equivelent to C<set_alpha(14)> or
-C<new(14)>.
+If all of the above seems really confusing, no worries: RSI(14) means
+C<set_alpha(14)> (or C<new(14)> and is equivelent to C<set_days(27)>.
 
 =head2 Cutler
 
@@ -216,17 +200,17 @@ You can switch between Wilder and Cutler mode with these:
     $rsi->set_standard; # for exponential moving averages
 
 WARNING: Both of these clear out the value queue!  If you need to track
-both, you'll need two objects. 
+both, you'll need two objects.
 
-=head1 Thanks
+=head1 THANKS
 
-Todd Litteken <cl@xganon.com> 
+Todd Litteken C<< <cl@xganon.com> >>
 
-Amit Dutt <amit_dutt@hotmail.com>                                                                                       
+Amit Dutt C<< <amit_dutt@hotmail.com> >>
 
 =head1 AUTHOR
 
-Paul Miller <jettero@cpan.org>
+Paul Miller C<< <jettero@cpan.org> >>
 
 I am using this software in my own projects...  If you find bugs, please please
 please let me know.
@@ -234,14 +218,25 @@ please let me know.
 I normally hang out on #perl on freenode, so you can try to get immediate
 gratification there if you like.  L<irc://irc.freenode.net/perl>
 
+There is also a mailing list with very light traffic that you might want to
+join: L<http://groups.google.com/group/stockmonkey/>.
+
 =head1 COPYRIGHT
 
-Copyright (c) 2008 Paul Miller -- LGPL [Software::License::LGPL_2_1]
+Copyright (c) 2010 Paul Miller
 
-    perl -MSoftware::License::LGPL_2_1 \
-         -e '$l = Software::License::LGPL_2_1->new({
-             holder=>"Paul Miller"});
-             print $l->fulltext' | less
+=head1 LICENSE
+
+This module is free software.  You can redistribute it and/or
+modify it under the terms of the Artistic License 2.0.
+
+This program is distributed in the hope that it will be useful,
+but without any warranty; without even the implied warranty of
+merchantability or fitness for a particular purpose.
+
+[This software may have had previous licenses, of which the current maintainer
+is completely unaware.  If this is so, it is possible the above license is
+incorrect or invalid.]
 
 =head1 SEE ALSO
 
