@@ -4,13 +4,13 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = 2.4;
+our $VERSION = 2.5;
 
 1;
 
 sub recommended { croak "no recommendation" }
 
-sub new { 
+sub new {
     my $class = shift;
     my $this  = bless {
         val => [],
@@ -26,8 +26,8 @@ sub new {
     return $this;
 }
 
-sub set_days { 
-    my $this = shift; 
+sub set_days {
+    my $this = shift;
     my $arg  = int(shift);
 
     croak "days must be a positive non-zero integer" if $arg <= 0;
@@ -82,8 +82,8 @@ Math::Business::SMA - Technical Analysis: Simple Moving Average
      $avg->set_days(7);
 
   my @closing_values = qw(
-      3 4 4 5 6 5 6 5 5 5 5 
-      6 6 6 6 7 7 7 8 8 8 8 
+      3 4 4 5 6 5 6 5 5 5 5
+      6 6 6 6 7 7 7 8 8 8 8
   );
 
   # choose one:
@@ -91,7 +91,7 @@ Math::Business::SMA - Technical Analysis: Simple Moving Average
   $avg->insert( $_ ) for @closing_values;
 
   if( defined(my $q = $avg->query) ) {
-      print "value: $q.\n";  
+      print "value: $q.\n";
 
   } else {
       print "value: n/a.\n";
@@ -103,7 +103,7 @@ For short, you can skip the set_days() by suppling the setting to new():
 
 =head1 AUTHOR
 
-Paul Miller <jettero@cpan.org>
+Paul Miller C<< <jettero@cpan.org> >>
 
 I am using this software in my own projects...  If you find bugs, please please
 please let me know.
@@ -116,12 +116,20 @@ join: L<http://groups.google.com/group/stockmonkey/>.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008 Paul Miller -- LGPL [Software::License::LGPL_2_1]
+Copyright (c) 2010 Paul Miller
 
-    perl -MSoftware::License::LGPL_2_1 \
-         -e '$l = Software::License::LGPL_2_1->new({
-             holder=>"Paul Miller"});
-             print $l->fulltext' | less
+=head1 LICENSE
+
+This module is free software.  You can redistribute it and/or
+modify it under the terms of the Artistic License 2.0.
+
+This program is distributed in the hope that it will be useful,
+but without any warranty; without even the implied warranty of
+merchantability or fitness for a particular purpose.
+
+[This software may have had previous licenses, of which the current maintainer
+is completely unaware.  If this is so, it is possible the above license is
+incorrect or invalid.]
 
 =head1 SEE ALSO
 
